@@ -10,8 +10,7 @@ use Cwd 'abs_path';
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.2';
-
+our $VERSION = '0.3';
 
 
 #------------------------------------------------------------------------------
@@ -1247,6 +1246,24 @@ sub comp_sorter {
 
 
 
+#------------------------------------------------------------------------------
+# collapse
+#
+sub collapse {
+	my ($val) = @_;
+	
+	if (defined $val) {
+		$val =~ s|^\s+||s;
+		$val =~ s|\s+$||s;
+		$val =~ s|\s+| |sg;
+	}
+	
+	return $val;
+}
+#
+# collapse
+#------------------------------------------------------------------------------
+
 
 #
 # private methods
@@ -1275,7 +1292,7 @@ F<miko@idocs.com>
 
 =head1 VERSION
 
-Version: 0.01
+Version: 0.03
 
 =head1 HISTORY
 
@@ -1289,6 +1306,9 @@ Initial release.
 
 Fixed dependency problem. Should not have been using String::Util.
 
+=item * Version 0.03 Aug 25, 2016
+
+Added private sub collapse() which should have been in there all along.
 
 =back
 
